=======
History
=======

0.1.1 (2020-04-27)
==================

Bug fixed:

* Handle error of using incorrect encoding to open a file.

0.1.0 (2020-04-25)
==================

First release on PyPI.

Features:

* File or whole project: can convert a single file or all files in your project.
* Patterns to ignore: use .gitignore syntax to exclude unwanted files.
